Learn R Programming

lefse (version 0.1)

com.trait.moments: com.trait.moments

Description

Quantifies the moments of the community trait distribution

Usage

com.trait.moments(my.sample, traits)

Arguments

my.sample
A community data matrix.
traits
A trait file with species names as row names and trait as columns.

Value

com.mean The mean trait value of the community com.sd The standard deviation of the trait values in the community com.skew The skewness of the trait values in the community com.kurt The kurtosis of the trait values in the community

Details

Quantifies the moments of the community trait distribution

References

Swenson, N.G. 2014. Functional and Phylogenetic Ecology in R. Springer UseR! Series, Springer, New York, New York, U.S.A.

See Also

com.trait.weighted

Examples

Run this code

data(lefse.sample)
data(lefse.traits)
com.trait.moments(lefse.sample, lefse.traits)



Run the code above in your browser using DataLab